#
# spec file for package entangle
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           entangle
Version:        3.0
Release:        bp155.3.9
Summary:        Tethered shooting & control of digital cameras
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://entangle-photo.org
Source0:        https://www.entangle-photo.org/download/sources/%{name}-%{version}.tar.xz
Source1:        https://www.entangle-photo.org/download/sources/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
# from upstream git
Patch0:         fix-new-meson.patch
BuildRequires:  gtk-doc
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gexiv2)
BuildRequires:  pkgconfig(glib-2.0) >= 2.36.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libgphoto2)
BuildRequires:  pkgconfig(libpeas-1.0)
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
Entangle is an application which uses GTK and libgphoto2 to provide a
graphical interface for tethered photography with digital cameras.

It includes control over camera shooting and configuration settings
and 'hands off' shooting directly from the controlling computer.

%package plugin-eclipse
Summary:        Eclipse totality automated capture for corona
Group:          Productivity/Graphics/Other
Requires:       %{name} = %{version}
Requires:       python3
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       typelib(GExiv2) = 0.10
Requires:       typelib(GstBase) = 1.0

%description plugin-eclipse
Entangle provides a graphical interface for "tethered shooting", aka
taking photographs with a digital camera completely controlled from
the computer.

This package provides the eclipse plugin for %{name}.

%package plugin-photobox
Summary:        Captive interface for public photo box
Group:          Productivity/Graphics/Other
Requires:       %{name} = %{version}
Requires:       python3
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       typelib(GExiv2) = 0.10
Requires:       typelib(GstBase) = 1.0

%description plugin-photobox
Entangle provides a graphical interface for "tethered shooting", aka
taking photographs with a digital camera completely controlled from
the computer.

This package provides the photobox plugin for %{name}.

%package plugin-shooter
Summary:        Repeated batch mode shooting
Group:          Productivity/Graphics/Other
Requires:       %{name} = %{version}
Requires:       python3
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       typelib(GExiv2) = 0.10
Requires:       typelib(GstBase) = 1.0

%description plugin-shooter
Entangle provides a graphical interface for "tethered shooting", aka
taking photographs with a digital camera completely controlled from
the computer.

This package provides the shooter plugin for %{name}.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
Entangle provides a graphical interface for "tethered shooting", aka
taking photographs with a digital camera completely controlled from
the computer.

Documentation for %{name}.

%package -n typelib-1_0-Entangle-0_1
Summary:        Introspection bindings for the %{name} plugins
Group:          Productivity/Graphics/Other

%description -n typelib-1_0-Entangle-0_1
Entangle provides a graphical interface for "tethered shooting", aka
taking photographs with a digital camera completely controlled from
the computer.

This package provides the GObject Introspection bindings for %{name}
plugins

%lang_package

%prep
%setup -q
%autopatch -p1

%build
%meson -Denable-gtk-doc=true
%meson_build

%install
%meson_install

# We do not provide a devel subpackage
find %{buildroot}%{_libdir}/ -type l -name "*.so" -delete -print
rm -rf %{buildroot}%{_datadir}/gir-1.0

%find_lang %{name} %{?no_lang_C}

%post
%glib2_gsettings_schema_post
/sbin/ldconfig

%postun
%glib2_gsettings_schema_postun
/sbin/ldconfig

%files
%doc AUTHORS ChangeLog NEWS README.rst
%{_bindir}/%{name}
%{_libdir}/lib%{name}_backend.so.*
%{_libdir}/lib%{name}_frontend.so.*
%{_datadir}/applications/org.entangle_photo.Manager.desktop
%{_datadir}/metainfo/org.entangle_photo.Manager.metainfo.xml
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/sRGB.icc
%{_datadir}/glib-2.0/schemas/org.%{name}-photo.manager.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*entangle*.??g
%{_mandir}/man?/%{name}.?%{ext_man}
%license COPYING

%files plugin-eclipse
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/eclipse
%dir %{_datadir}/%{name}/plugins
%{_datadir}/%{name}/plugins/eclipse

%files plugin-photobox
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/photobox
%dir %{_datadir}/%{name}/plugins
%{_datadir}/%{name}/plugins/photobox

%files plugin-shooter
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/shooter
%dir %{_datadir}/%{name}/plugins
%{_datadir}/%{name}/plugins/shooter

%files doc
%doc %{_datadir}/help/C/%{name}
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/%{name}

%files -n typelib-1_0-Entangle-0_1
%{_libdir}/girepository-1.0/Entangle-0.1.typelib

%files lang -f %{name}.lang

%changelog
* Tue Mar  1 2022 Marcus Meissner <meissner@suse.com>
- fix-new-meson.patch: fix build with new meson
* Thu Aug 27 2020 Marcus Meissner <meissner@suse.com>
- fixed filelists after update to make it build.
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.0:
  * Ensure picture directory is an absolute path
  * Add ability to flip image during preview
  * Fix warnings about string length
  * Convert appdata file to metainfo and add missing info
  * Another attempt to fix build deps on enum headers
  * Display remaining shot count & ETA in repeat shooter
  plugin
  * Remove use of deprecated GObject macros
  * Remove use of deprecated GLib APIs
  * Ensure glib min version checks at build time
  * Convert to use GObject macros for declaring boilerplate
  * Bulk reformat code using clang-format rules
  * Force a default filename pattern if setting is invalid
  * Validate filename pattern when updating preferences
  * Rename desktop file and icon file to match application ID
  * Add ability to render text mesages over image
  * Add a countdown timer for photobox plugin capture
  * Disable context menu in image browser when photobox plugin
  is active
  * Run live view when counting down to capturein photobox
  plugin
  * Fix crash releasing popup windows
  * Add context menu option for opening popup image window
  * Drop drag support for opening popup image window
  * Display greeting when opening popup image window
  * Display greeting when entering photobox plugin
* Tue Jan 22 2019 Андрей Алыпов <and.november@opensuse.org>
- update to version 2.0
  * Require gobject introspection >= 1.54
  * Require GTK3 >= 3.22
  * Fix dependency on libraw
  * Fix variable name in photobox plugin
  * Document some missing keyboard shortcuts
  * Fix upper bound in histogram to display clipped pixel
  * Refresh translations
  * Option to highlight over exposed pixels in red
  * Disable noisy compiler warning
  * Remove use of deprecated application menu concept
  * Fix image redraw when changing some settings
  * Update mailing list address in appdaat
  * Add more fields to appdata content
  * Fix reference counting during window close
  * Use correct API for destroying top level windows
  * Fix unmounting of cameras with newer gvfs URI naming scheme
  * Avoid out of bounds read of property values
  * Fix many memory leaks
  * Workaround for combo boxes not displaying on Wayland
  * Fix race condition in building enums
  * Fix setting of gschema directory during startup
  * Set env to ensure plugins can find introspection typelib
- entangle-desktop.patch: dropped, included desktop file is ok
* Fri Jul 21 2017 tchvatal@suse.com
- Update to 0.7.1:
  * Fix linking problem with strict linkers
  * Misc spelling fixes to online help docs
  * Replace use of GSimpleAsyncResult with GTask
  * Specify versions when importing from python plugins
  * Remove use of deprecated GTK APIs
  * Render image stats overlay partially transparent
  * Fix error reporting when saving settings
  * Flush events after capture to avoid accidentally restarting preview
  * Make Nikon fine focus stepping finer
  * Ensure images are sorted by last modified date
  * Switch from 128 px to 256 px thumbnail sizes to benefit larger high dpi screens
  * Rewrite film strip browser to dynamically resize icons to fit available space
  * Draw symbolic icons in film strip if image is not yet loaded
  * Refresh translations from Zanata
- Depend on lcms2 not lcms1
* Tue Dec  8 2015 p.drouand@gmail.com
- Update to version 0.7.0
  * Require GLib >= 2.36
  * Import new logo design
  * Switch to using zanata.org for translations
  * Set default window icon
  * Introduce an initial help manual via yelp
  * Use shared library for core engine to ensure all symbols
  are exported to plugins
  * Add framework for scripting capture operations
  * Workaround camera busy problems with Nikon cameras
  * Add a plugin for repeated capture sequences
  * Replace progress bar with spinner icon
- Changes from version 0.6.1
  * Require GTK >= 3.4
  * Fix check for GIO package in configure
  * Add missing icons to Makefile
  * Follow freedesktop thumbnail standard storage location
  * Refactor capture code to facilitate plugin script
    automation
  * Fix bug causing plugin to be displayed more than once
  * Make histogram height larger
  * Strip trailing '2' from widget labels to be more friendly
  * Completely rewrite control panel display to show a small,
    user configurable subset from all the camera controls.
  * Remember custom list of camera controls per camera model
  * Hide compiler warnings from new glib atomic opertaions
  * Update to newer gnulib compiler warnings code
  * Remove broken double buffering code that's no required
    when using GTK3
  * Remove use of deprecated GtkMisc APis
  * Allow camera picker list to show multiple lines
  * Remove crufty broken code from session browser that was
  breaking with new GTK versions
  * Disable libraw auto brightness since it totally overexposes
    many images, generally making things look worse
  * Fix memory leak handling camera events
  * Add keywords to desktop & appdata files
- Add gtk-doc and itstool dependencies
- Add yelp-tools require but disable it for now as the check
  now requires internet connection
- Disable check; requires network connection
- Split out photobox and shooter plugins into their own packages
- Recommend entangle-lang package
- Update entangle-desktop.patch
* Sat May  3 2014 meissner@suse.com
- Release 0.6.0 - "Down" - 2014-05-02
  * Add a demonstration plugin for setting up a captive photo box display mode
  * Switch to use Python3 for plugin engine instead of JavaScript
  * Use GTK dark theme
  * Require GNOME symbolic icon theme to be installed
  * Switch to require lcms2 instead of lcms
  * Move application icon into a standard directory mandated to work with the appdata tools
  * Make manual focus work with Canon EOS cameras
  * Disable flickering progress bar in preview mode with Canon EOS cameras
  * Remove use of deprecated GTK methods/classes/constants
  * Remove use of gexiv2 method which is not long exported
  * Remove use of deprecated libpeas methods
  * Add GTK-DOC transfer annotations / docs to all methods
  * Avoid loosing camera capabilities on disconnect
  * Fix off by one in histogram tables causing memory corruption
  * Mark appdata / desktop files for translation
  * Fix typos in README file
  * Fix inverted tests when checking if range widget changed
  * Avoid storm of expose events due to auto-drawer widget
  * Avoid never ending circular update of controls causing errors in some camera modes
  * Add workaround for crazy D5100 camera serial number
  * Add customizable highlight/background for images
  * Avoid reference leak of windows preventing proper cleanup
  * Remove camera manual/about/driver help windows since it did not contain any info useful to users
  * Filter list of cameras in connect dialog to only those which support capture/preview
  * Don't auto connect to cameras which don't support capture or preview
  * Ensure parent window is set on dialogs to prevent them falling behind main window
  * Fix crash with latest GTK due to incorrect overriding of GtkApplication startup method
  * Update to cope with changed GExiv API version
  * Refreshed translations from transifex
* Wed Dec 18 2013 meissner@suse.com
- Release 0.5.4 - "Up" - 2013-12-15
  * Ensure thumbnail directory exists when saving thumbnails
  * Fix memory leak generating thumbnails from raw images
  * Add an appdata XML file for GNOME software center
  * Create a dedicated camera actions menu
  * Fix include of gexiv2 header files
  * Fix image selection for onion skinning in preview mode
  * Display selected image when cancelling preview
  * Fix empty tooltips on capture/preview buttons
  * Fix scaling for preview image in onion skinning mode
  * Increase emphasis of top image in onion skinning mode
  * Improve granularity of manual focus and add extra
  '<' and '>' key accelerators for coarse focus
  * Fix leak of image exiting preview mode
  * Make progress toolbar button permanently visible
* Thu Aug 29 2013 meissner@suse.com
- Release 0.5.3 - "Photon" - 2013-08-28
  * Move file name of image thumbnails to tooltip popup
  * Add --disable-schemas-compile configure arg to
    disable schema compilation
  * Remove "Encoding" key from desktop file
  * Fix massive memory leak in pixbuf loading
  * Fix thread safety in camera control updates which caused
    hangs in GTK
  * Fix updating of control readonly state when camera modes
    change
- Release 0.5.2 - "Graviton" - 2013-08-17
  * Split histogram into RGB colour channels
  * Fix aperture / shutter speed calculations in status bar
  * Only import files with known image extensions
  * Use case insensitive file extension check to detect raw files
  * Set saner defaults for processing raw files to fix Canon
    raw display
  * Set preferences before loading session to fix settings
    for initial image load
  * Apply orientation from EXIF images if image file has none
  * Remove left over debug prints
  * Add support for linear histogram display mode
  * Support 'h' key to toggle linear/log histogram mode
  * Ensure all events are emitted in main thread
  * Remove use of deprecated GDK thread APIs
  * Use GtkGrid instead of deprecated GtkTable
  * Ensure status bar is constant size when scaling image
  * Preserve scrollbar offsets when switching images
  * Make metadata extraction more robust wrt missing fields
  * Updated translations from transifex
- Release 0.5.1 - "W Boson" - 2012-03-12
  * Update for compatibility with libgphoto 2.5 API
    callbacks
  * Avoid warnings about deprecated glib2 mutex
    and condition variable APIs
  * Directly disable viewfinder mode using config APIs
  * Add support for triggering autofocus during preview
    with 'a' key
  * Add support for manual focus drive in/out using
    '.' and ',' keys
  * Refresh translations from transifex
  * Import user contributed Italian translation
  * Add missing translation markers on some strings
- Release 0.5.0 - "Z Boson" - 2012-12-16
  * Switch to using LibRaw for loading raw images
  * Allowing loading image preview from raw files
  * Fix deadlock unmounting camera at startup
  * Ensure camera is disconnected before exiting
  * Sort image list by name instead of date
  * Add support for rendering "onion skin" of image sequence
  * Fix updating of range control values
  * Fix filename generation for dual-format capture modes
  * Fix deletion of dual-format images when exiting preview
  * Refresh translations
- removed entangle-libgphoto25.patch: upstream
- updated entangle-desktop.patch
* Thu Feb 14 2013 meissner@suse.com
- entangle-libgphoto25.patch: libgphoto2 2.5 port.
* Tue Sep 25 2012 p.drouand@gmail.com
- Updated to 0.4.1
  * Fix leak of image pixbufs when changing image in session
  * Keep toolbar directory in sync with session dir
  * Fix leak when displaying image popups
  * Fix leak when closing image popups
  * Fix key bindings in session browser
  * Add image histogram display
  * Load libpeas introspection data for plugins
  * Main plugin list in preferences
  * Add object type checking in all APIs
  * Fix image mask aspect ratio conversion to avoid locale problems
  * Fix build on GTK < 3.4
  * Remove obsolete conditionals from GTK 2.x days
  * Populate list of supported cameras in help menu dialog
  * Add a simple man page
  * Add accelerators for many menu options
  * Fix unref of cairo surface objects
  * Avoid GTK assertion when range is max-min is zero
  * Avoid crash in control panel when updating after camera disconnect
* Thu May 31 2012 meissner@suse.de
- Updated to 0.3.3
  * Fix deadlock when starting app with glib >= 2.32
  * Remove use of deprecated API calls
  * Remove use of deprecated GTK widgets
  * Fix debugging with glib >= 2.32
  * Fix creation of session browser widget to avoid warnings
  * Refresh translations
  * Fix check for glib-compile-schemas binary
* Thu May 31 2012 meissner@suse.de
- buildrequire glib2-tools
* Wed Feb 22 2012 meissner@suse.de
- Updated to the current stable release is 0.3.1
  * Fix crash in handling camera control combo lists
  * Add notice about need to set XDG_DATA_DIRS when
    installing into unusual directories
  * Add workaround to avoid immediate crash if schemas
    were not found in XDG_DATA_DIRS
  * Compile schema files after installation
  * Fix crash updating widget sensitivity
  * Fix crashes & race conditions during capture of images
  * Fix infinite preview error message popups which can
    hang the window manager
  * Fix crash when retrying a failed connection attempt
  * Fix thread locking when hiding status display
  * Avoid running multiple threads for monitoring status
  * Fix initial sensitivity of camera control panels
  * Update README with new URLs for bugs/mailing lists
* Tue Jun  8 2010 meissner@suse.de
- new version of photobooth / gtk program
